@@ -4,15 +4,18 @@ from ._tqdm_gui import tqdm_gui
 from ._tqdm_gui import tgrange
 from ._tqdm_pandas import tqdm_pandas
 from ._main import main
-from ._monitor import TMonitor
+from ._monitor import TMonitor, TqdmSynchronisationWarning
 from ._version import __version__  # NOQA
-from ._tqdm import TqdmTypeError, TqdmKeyError, TqdmDeprecationWarning, \
+from ._tqdm import TqdmTypeError, TqdmKeyError, TqdmWarning, \
+    TqdmDeprecationWarning, TqdmExperimentalWarning, \
     TqdmMonitorWarning
 
 __all__ = ['tqdm', 'tqdm_gui', 'trange', 'tgrange', 'tqdm_pandas',
            'tqdm_notebook', 'tnrange', 'main', 'TMonitor',
-           'TqdmTypeError', 'TqdmKeyError', 'TqdmDeprecationWarning',
-           'TqdmMonitorWarning',
+           'TqdmTypeError', 'TqdmKeyError',
+           'TqdmWarning', 'TqdmDeprecationWarning',
+           'TqdmExperimentalWarning',
+           'TqdmMonitorWarning', 'TqdmSynchronisationWarning',
            '__version__']
 
 
